@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 """OPEM parameters."""
-Version = 1.3
-Website = "http://www.ecsim.ir/opem"
-UpdateUrl = "http://www.ecsim.ir/opem/update"
+Version = 1.4
+Website = "http://www.ecsim.site/opem"
+UpdateUrl = "http://www.ecsim.site/opem/update"
 Overview = '''
 Modeling and simulation of proton-exchange membrane fuel cells (PEMFC) may work as a
 powerful tool in the research & development of renewable energy sources. The Open-Source
@@ -17,9 +17,9 @@ and some others take into account a part or all auxiliaries such as reformers. O
 a platform for collaborative development of PEMFC models.'''
 
 Links = '''
-Website : http://www.ecsim.ir/opem
+Website : http://www.ecsim.site/opem
 Repository : https://github.com/ECSIM/opem
-Document : http://www.ecsim.ir/opem/doc/
+Document : http://www.ecsim.site/opem/doc/
 Paper : https://doi.org/10.21105/joss.00676
 * If you use OPEM in your research, please cite our paper
 * OPEM GUI is available here : https://github.com/ECSIM/gopem
@@ -49,9 +49,9 @@ HTML_Init_Template = """<!DOCTYPE html>
 <meta name="description" content="The Open-Source PEMFC Simulation Tool (OPEM) is an open-source mathematical simulation package for polymer electrolyte fuel cells">
 <meta name="og:title" content="OPEM Report ({1} Model)">
 <meta name="og:description" content="The Open-Source PEMFC Simulation Tool (OPEM) is an open-source mathematical simulation package for polymer electrolyte fuel cells">
-<meta name="og:url" content="http://opem.ecsim.ir">
-<meta property="og:image" content="http://www.ecsim.ir/opem/images/opem-og.png">
-<meta name="twitter:image:src" content="http://www.ecsim.ir/opem/images/opem-og.png">
+<meta name="og:url" content="http://opem.ecsim.site">
+<meta property="og:image" content="http://www.ecsim.site/opem/images/opem-og.png">
+<meta name="twitter:image:src" content="http://www.ecsim.site/opem/images/opem-og.png">
 <meta name="twitter:card" content="summary_large_image">
 <meta name="twitter:title" content="OPEM Report ({1} Model)">
 <meta name="twitter:description" content="The Open-Source PEMFC Simulation Tool (OPEM) is an open-source mathematical simulation package for polymer electrolyte fuel cells">
@@ -91,7 +91,7 @@ HTML_Overall_Params_Table_Template = """
 """
 
 HTML_End_Template = """
-<p style="text-align:center;border-top:1px solid black;">Generated By <a style="text-decoration:none;color:#ff7600;" href="http://opem.ecsim.ir">OPEM</a> Version {0}</p>
+<p style="text-align:center;border-top:1px solid black;">Generated By <a style="text-decoration:none;color:#ff7600;" href="http://opem.ecsim.site">OPEM</a> Version {0}</p>
 """
 
 Amphlett_InputParams = {
@@ -544,14 +544,14 @@ Description_Menu = {
 Mode_Menu = "\n\n[M]: More information\n\n[T]: Run standard test vector\n\n[P]: Enter your parameters (*default)\n\nPlease select a mode : "
 
 Description_Links = {
-    "Amphlett_Analysis (Static)": "http://www.ecsim.ir/opem/doc/Static/Amphlett.html",
-    "Larminiee_Analysis (Static)": "http://www.ecsim.ir/opem/doc/Static/Larminie_Dicks.html",
-    "Chamberline_Kim_Analysis (Static)": "http://www.ecsim.ir/opem/doc/Static/Chamberline_Kim.html",
-    "Padulles_Analysis I (Dynamic)": "http://www.ecsim.ir/opem/doc/Dynamic/Padulles1.html",
-    "Padulles_Analysis II (Dynamic)": "http://www.ecsim.ir/opem/doc/Dynamic/Padulles2.html",
-    "Padulles_Hauer Analysis (Dynamic)": "http://www.ecsim.ir/opem/doc/Dynamic/Padulles_Hauer.html",
-    "Padulles_Amphlett Analysis (Dynamic)": "http://www.ecsim.ir/opem/doc/Dynamic/Padulles_Amphlett.html",
-    "Chakraborty_Analysis (Dynamic)": "http://www.ecsim.ir/opem/doc/Dynamic/Chakraborty.html"}
+    "Amphlett_Analysis (Static)": "http://www.ecsim.site/opem/doc/Static/Amphlett.html",
+    "Larminiee_Analysis (Static)": "http://www.ecsim.site/opem/doc/Static/Larminie_Dicks.html",
+    "Chamberline_Kim_Analysis (Static)": "http://www.ecsim.site/opem/doc/Static/Chamberline_Kim.html",
+    "Padulles_Analysis I (Dynamic)": "http://www.ecsim.site/opem/doc/Dynamic/Padulles1.html",
+    "Padulles_Analysis II (Dynamic)": "http://www.ecsim.site/opem/doc/Dynamic/Padulles2.html",
+    "Padulles_Hauer Analysis (Dynamic)": "http://www.ecsim.site/opem/doc/Dynamic/Padulles_Hauer.html",
+    "Padulles_Amphlett Analysis (Dynamic)": "http://www.ecsim.site/opem/doc/Dynamic/Padulles_Amphlett.html",
+    "Chakraborty_Analysis (Dynamic)": "http://www.ecsim.site/opem/doc/Dynamic/Chakraborty.html"}
 Vectors = {
     "Amphlett_Analysis (Static)": Amphlett_Standard_Vector,
     "Larminiee_Analysis (Static)": Larminiee_Standard_Vector,
